"use client";

import Image from "next/image";

import { motion } from "framer-motion";

import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { ProductDetailsBlogStatisticsData } from "@/utils/get-fake-data";

interface ProductDetailsBlogStatisticsClientProps {
	data: ProductDetailsBlogStatisticsData;
	locale: Locale;
}

export function ProductDetailsBlogStatisticsClient({
	data,
	locale,
}: ProductDetailsBlogStatisticsClientProps) {
	const isRTL = locale === "ar";

	return (
		<section className="container mx-auto py-16">
			<div className="grid md:grid-cols-2 lg:h-[682px] lg:grid-cols-4">
				{data.items?.map((stat, index) => (
					<motion.div
						key={stat.id}
						initial={{ opacity: 0, y: 20 }}
						animate={{ opacity: 1, y: 0 }}
						transition={{ delay: index * 0.1 }}
						className={cn(
							"relative overflow-hidden p-6",
							stat.backgroundColor || "bg-transparent"
						)}
					>
						{stat.image && (
							<div className="absolute inset-0">
								<Image src={stat.image} alt="" fill className="object-cover" />
								<div className="absolute inset-0 bg-black/40" />
							</div>
						)}
						<div
							className={cn(
								"relative flex h-full flex-col items-center justify-around space-y-4"
							)}
						>
							<p className="text-5xl text-white lg:text-6xl">{stat.value}</p>
							<div>
								<h3
									className={cn(
										"mb-4 text-xl text-white",
										isRTL && "font-arabic"
									)}
								>
									{stat.title?.[locale]}
								</h3>
								<p
									className={cn(
										"text-sm text-white/80",
										isRTL && "font-arabic"
									)}
								>
									{stat.description?.[locale]}
								</p>
							</div>
						</div>
					</motion.div>
				))}
			</div>
		</section>
	);
}
